@@ -1747,7 +1747,9 @@ function bundle_libs
          ($3 !~ /\/libICE\./) &&
          ($3 !~ /\/libSM\./) &&
          ($3 !~ /\/libX11\./) &&
+         ($3 !~ /\/libX11-xcb\./) &&
          ($3 !~ /\/libanl\./) &&
+         ($3 !~ /\/libatk-1.0\./) &&
          ($3 !~ /\/libasound\./) &&
          ($3 !~ /\/libc\./) &&
          ($3 !~ /\/libcairo\./) &&
@@ -1785,6 +1787,7 @@ function bundle_libs
          ($3 !~ /\/libnss_hesiod\./) &&
          ($3 !~ /\/libnss_nis\./) &&
          ($3 !~ /\/libnss_nisplus\./) &&
+         ($3 !~ /\/libOpenGL\./) &&
          ($3 !~ /\/libp11-kit\./) &&
          ($3 !~ /\/libpango-1.0\./) &&
          ($3 !~ /\/libpangocairo-1.0\./) &&
@@ -1900,6 +1903,7 @@ function deploy_mac
     log fixing rpath of executable "$exe"
     cmd install_name_tool -delete_rpath "$FINAL_INSTALL_DIR/lib" "$exe" 2> /dev/null
     cmd install_name_tool -delete_rpath "$QTDIR/lib" "$exe" 2> /dev/null
+    cmd install_name_tool -delete_rpath "/opt/local/lib" "$exe" 2> /dev/null
     cmd install_name_tool -add_rpath "@executable_path/../Frameworks" "$exe"
   done
   cmd cp -p /opt/local/lib/libaom.3.dylib Frameworks
@@ -1911,6 +1915,8 @@ function deploy_mac
   log fixing rpath of executable "whisper-cli"
   cmd install_name_tool -delete_rpath "$SOURCE_DIR"/whisper.cpp/build/src MacOS/whisper-cli 2> /dev/null
   cmd install_name_tool -delete_rpath "$SOURCE_DIR"/whisper.cpp/build/ggml/src MacOS/whisper-cli 2> /dev/null
+  cmd install_name_tool -delete_rpath "$SOURCE_DIR"/whisper.cpp/build/ggml/src/ggml-blas MacOS/whisper-cli 2> /dev/null
+  cmd install_name_tool -delete_rpath "$SOURCE_DIR"/whisper.cpp/build/ggml/src/ggml-metal MacOS/whisper-cli 2> /dev/null
   cmd install_name_tool -add_rpath "@executable_path/../Frameworks" MacOS/whisper-cli
 
   # MLT plugins
