@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2014-2024 Meltytech, LLC
+ * Copyright (c) 2014-2025 Meltytech, LLC
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -47,6 +47,7 @@ public:
     void onUndoOrRedo(Mlt::Service &service);
     int currentIndex() const { return m_currentFilterIndex; }
     void addOrEditFilter(Mlt::Filter *filter, const QStringList &key_properties);
+    void setTrackTransitionService(const QString &service);
 
 protected:
     void timerEvent(QTimerEvent *);
@@ -62,6 +63,7 @@ public slots:
     void setCurrentFilter(int attachedIndex);
     void onFadeInChanged();
     void onFadeOutChanged();
+    void onGainChanged();
     void onServiceInChanged(int delta, Mlt::Service *service = 0);
     void onServiceOutChanged(int delta, Mlt::Service *service = 0);
     void removeCurrent();
