@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2013-2024 Meltytech, LLC
+ * Copyright (c) 2013-2026 Meltytech, LLC
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -51,10 +51,10 @@ FiltersDock::FiltersDock(MetadataModel *metadataModel,
 {
     LOG_DEBUG() << "begin";
     setObjectName("FiltersDock");
-    QIcon filterIcon = QIcon::fromTheme("view-filter",
-                                        QIcon(":/icons/oxygen/32x32/actions/view-filter.png"));
-    setWindowIcon(filterIcon);
-    toggleViewAction()->setIcon(windowIcon());
+    setWhatsThis("https://forum.shotcut.org/t/about-filters/48127/1");
+    QIcon icon = QIcon::fromTheme("view-filter",
+                                  QIcon(":/icons/oxygen/32x32/actions/view-filter.png"));
+    toggleViewAction()->setIcon(icon);
     setMinimumSize(200, 200);
     setupActions();
 
@@ -106,6 +106,7 @@ void FiltersDock::setCurrentFilter(QmlFilter *filter, QmlMetadata *meta, int ind
     QMetaObject::invokeMethod(m_qview.rootObject(),
                               "setCurrentFilter",
                               Q_ARG(QVariant, QVariant(index)));
+    m_qview.setWhatsThis(meta ? meta->helpText() : QString());
 }
 
 bool FiltersDock::event(QEvent *event)
