@@ -40,11 +40,13 @@
 
 ScreenCaptureJob::ScreenCaptureJob(const QString &name,
                                    const QString &filename,
-                                   const QRect &captureRect)
+                                   const QRect &captureRect,
+                                   bool recordAudio)
     : AbstractJob(name, QThread::NormalPriority)
     , m_filename(filename)
     , m_rect(captureRect)
     , m_isAutoOpen(true)
+    , m_recordAudio(recordAudio)
 {
     QAction *action = new QAction(tr("Open"), this);
     action->setToolTip(tr("Open the capture"));
@@ -97,10 +99,12 @@ void ScreenCaptureJob::start()
     args << "-video_size" << QString("%1x%2").arg(m_rect.width()).arg(m_rect.height());
     args << "-i"
          << "desktop";
-    args << "-f"
-         << "dshow";
-    args << "-i"
-         << "audio=" + Settings.audioInput();
+    if (m_recordAudio) {
+        args << "-f"
+             << "dshow";
+        args << "-i"
+             << "audio=" + Settings.audioInput();
+    }
     if (Settings.encodeUseHardware() && !Settings.encodeHardware().isEmpty()) {
         vcodec = "h264_mf";
         args << "-rate_control"
@@ -119,27 +123,45 @@ void ScreenCaptureJob::start()
     args << "-video_size" << QString("%1x%2").arg(m_rect.width()).arg(m_rect.height());
     args << "-i"
          << ":0.0";
-    args << "-f"
-         << "pulse";
-    args << "-i" << Settings.audioInput();
-    if (Settings.encodeUseHardware() && Settings.encodeHardware().contains("h264_vaapi")) {
-        vcodec = "h264_vaapi";
-        args << "-qp"
-             << "18";
-        args << "-init_hw_device"
-             << "vaapi=vaapi0:";
-        args << "-filter_hw_device"
-             << "vaapi0";
-        args << "-vf"
-             << "format=nv12,hwupload";
-        args << "-quality"
-             << "1";
-        args << "-rc_mode"
-             << "CQP";
+    if (m_recordAudio) {
+        args << "-f"
+             << "pulse";
+        args << "-i" << Settings.audioInput();
+    }
+    if (Settings.encodeUseHardware() && !Settings.encodeHardware().isEmpty()) {
+        if (Settings.encodeHardware().contains("h264_nvenc")) {
+            vcodec = "h264_nvenc";
+            args << "-preset"
+                 << "p4";
+            args << "-tune"
+                 << "hq";
+            args << "-rc"
+                 << "vbr";
+            args << "-cq"
+                 << "19";
+            args << "-b:v"
+                 << "0";
+        } else if (Settings.encodeHardware().contains("h264_vaapi")) {
+            vcodec = "h264_vaapi";
+            args << "-qp"
+                 << "18";
+            args << "-init_hw_device"
+                 << "vaapi=vaapi0:";
+            args << "-filter_hw_device"
+                 << "vaapi0";
+            args << "-vf"
+                 << "format=nv12,hwupload";
+            args << "-quality"
+                 << "1";
+            args << "-rc_mode"
+                 << "CQP";
+        }
 #endif
     } else {
         args << "-crf"
              << "18";
+        args << "-preset"
+             << "veryfast";
         args << "-tune"
              << "film";
         args << "-pix_fmt"
@@ -201,7 +223,7 @@ void ScreenCaptureJob::stop()
     }
     if (m_dbusService != DBusService::None) {
         AbstractJob::stop();
-        resetKilled();
+        setKilled(false);
         return;
     }
 #endif
@@ -222,6 +244,7 @@ void ScreenCaptureJob::onFinished(int exitCode, QProcess::ExitStatus exitStatus)
 {
     m_progressTimer.stop();
 
+    LOG_DEBUG() << "screen capture job finished with exit code" << exitCode;
 #if defined(Q_OS_UNIX) && !defined(Q_OS_MAC)
     if (m_dbusService == DBusService::GNOME) {
         LOG_INFO() << "job succeeeded";
