@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2020-2025 Meltytech, LLC
+ * Copyright (c) 2020-2026 Meltytech, LLC
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,6 +18,7 @@
 #include "proxymanager.h"
 
 #include "Logger.h"
+#include "dialogs/longuitask.h"
 #include "jobqueue.h"
 #include "jobs/ffmpegjob.h"
 #include "jobs/qimagejob.h"
@@ -105,7 +106,10 @@ void ProxyManager::generateVideoProxy(Mlt::Producer &producer,
 
     // Touch file to make it in progress
     QFile file(fileName);
-    file.open(QIODevice::WriteOnly);
+    if (!file.open(QIODevice::WriteOnly)) {
+        LOG_ERROR() << "Failed to open file for writing:" << fileName;
+        return;
+    }
     file.resize(0);
     file.close();
 
@@ -379,7 +383,10 @@ void ProxyManager::generateImageProxy(Mlt::Producer &producer, bool replace)
 
     // Touch file to make it in progress
     QFile file(fileName);
-    file.open(QIODevice::WriteOnly);
+    if (!file.open(QIODevice::WriteOnly)) {
+        LOG_ERROR() << "Failed to open file for writing:" << fileName;
+        return;
+    }
     file.resize(0);
     file.close();
 
@@ -443,7 +450,7 @@ static void processProperties(QXmlStreamWriter &newXml,
         propertiesRef = newProperties;
     }
     // Write all of the property elements
-    for (const auto &p : propertiesRef) {
+    for (auto &p : propertiesRef) {
         newXml.writeStartElement("property");
         newXml.writeAttribute("name", p.first);
         newXml.writeCharacters(p.second);
@@ -765,9 +772,13 @@ public:
 void ProxyManager::generateIfNotExistsAll(Mlt::Producer &producer)
 {
     FindNonProxyProducersParser parser;
+    LongUiTask longTask(QObject::tr("Generating Proxies"));
     parser.start(producer);
+    auto n = parser.producers().size();
+    auto i = 0;
     for (auto &clip : parser.producers()) {
-        generateIfNotExists(clip, false /* replace */);
+        longTask.reportProgress(QFileInfo(ProxyManager::resource(clip)).fileName(), i++, n);
+        generateIfNotExists(clip, true /* replace */);
     }
 }
 
