@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2013-2023 Meltytech, LLC
+ * Copyright (c) 2013-2026 Meltytech, LLC
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -31,6 +31,7 @@ class QmlKeyframesParameter : public QObject
     Q_PROPERTY(QString name MEMBER m_name NOTIFY changed)
     Q_PROPERTY(QString property MEMBER m_property NOTIFY changed)
     Q_PROPERTY(QStringList gangedProperties MEMBER m_gangedProperties NOTIFY changed)
+    Q_PROPERTY(QStringList gangedRectProperties MEMBER m_gangedRectProperties NOTIFY changed)
     Q_PROPERTY(bool isCurve MEMBER m_isCurve NOTIFY changed)
     Q_PROPERTY(double minimum MEMBER m_minimum NOTIFY changed)
     Q_PROPERTY(double maximum MEMBER m_maximum NOTIFY changed)
@@ -49,6 +50,7 @@ public:
     QString name() const { return m_name; }
     QString property() const { return m_property; }
     QStringList gangedProperties() const { return m_gangedProperties; }
+    QStringList gangedRectProperties() const { return m_gangedRectProperties; }
     bool isCurve() const { return m_isCurve; }
     double minimum() const { return m_minimum; }
     double maximum() const { return m_maximum; }
@@ -64,6 +66,7 @@ private:
     QString m_name;
     QString m_property;
     QStringList m_gangedProperties;
+    QStringList m_gangedRectProperties;
     bool m_isCurve;
     double m_minimum;
     double m_maximum;
@@ -144,6 +147,7 @@ class QmlMetadata : public QObject
     Q_PROPERTY(QString keywords MEMBER m_keywords NOTIFY changed)
     Q_PROPERTY(QString icon READ iconFilePath WRITE setIconFileName NOTIFY changed)
     Q_PROPERTY(bool seekReverse MEMBER m_seekReverse NOTIFY changed)
+    Q_PROPERTY(QString help MEMBER m_helpText NOTIFY changed)
 
 public:
     enum PluginType {
@@ -208,6 +212,7 @@ public:
     bool isMltVersion(const QString &version);
     QString keywords() const { return m_keywords; }
     bool seekReverse() const { return m_seekReverse; }
+    QString helpText() const { return m_helpText; }
 
 signals:
     void changed();
@@ -235,6 +240,7 @@ private:
     QString m_keywords;
     QString m_icon;
     bool m_seekReverse;
+    QString m_helpText;
 };
 
 #endif // QMLMETADATA_H
