@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2013-2024 Meltytech, LLC
+ * Copyright (c) 2013-2026 Meltytech, LLC
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -81,6 +81,7 @@ class ShotcutSettings : public QObject
 public:
     static const qsizetype MaxPath{32767};
     enum TimelineScrolling { NoScrolling, CenterPlayhead, PageScrolling, SmoothScrolling };
+    enum ProcessingMode { Native8Cpu, Linear8Cpu, Native10Cpu, Linear10Cpu, Linear10GpuCpu };
 
     static ShotcutSettings &singleton();
     void log();
@@ -124,6 +125,10 @@ public:
     void setExportFrameSuffix(const QString &suffix);
     bool convertAdvanced() const;
     void setConvertAdvanced(bool);
+    ProcessingMode processingMode();
+    void setProcessingMode(ProcessingMode mode);
+    QString processingModeStr(ProcessingMode mode);
+    ProcessingMode processingModeId(const QString &mode);
 
     // encode
     QString encodePath() const;
@@ -134,6 +139,8 @@ public:
     void setEncodeUseHardware(bool);
     QStringList encodeHardware() const;
     void setEncodeHardware(const QStringList &);
+    bool encodeHardwareDecoder() const;
+    void setEncodeHardwareDecoder(bool);
     bool encodeAdvanced() const;
     void setEncodeAdvanced(bool);
     bool showConvertClipDialog() const;
@@ -149,7 +156,6 @@ public:
     QString playerExternal() const;
     void setPlayerExternal(const QString &);
     bool playerGPU() const;
-    void setPlayerGPU(bool);
     bool playerWarnGPU() const;
     QString playerInterpolation() const;
     void setPlayerInterpolation(const QString &);
@@ -175,6 +181,9 @@ public:
     void setPlayerZoom(float);
     int playerPreviewScale() const;
     void setPlayerPreviewScale(int);
+    bool playerPreviewHardwareDecoder() const;
+    bool playerPreviewHardwareDecoderIsSet() const;
+    void setPlayerPreviewHardwareDecoder(bool);
     int playerVideoDelayMs() const;
     void setPlayerVideoDelayMs(int);
     double playerJumpSeconds() const;
@@ -387,6 +396,10 @@ public:
     double speechSpeed() const;
     void setSpeechSpeed(double speed);
 
+    // Color Dialog
+    void saveCustomColors();
+    void restoreCustomColors();
+
 public slots:
     void reset();
 
