@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2014-2025 Meltytech, LLC
+ * Copyright (c) 2014-2026 Meltytech, LLC
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -42,6 +42,8 @@
 #include <QMediaDevices>
 #include <QMessageBox>
 #include <QProcess>
+#include <QProcessEnvironment>
+#include <QRegularExpression>
 #include <QStandardPaths>
 #include <QStorageInfo>
 #include <QStringList>
@@ -126,7 +128,7 @@ void Util::showInFolder(const QString &path)
     if (!QProcess::execute("/usr/bin/osascript", args))
         return;
 #endif
-    QDesktopServices::openUrl(QUrl::fromLocalFile(info.isDir() ? path : info.path()));
+    Util::openUrl(QUrl::fromLocalFile(info.isDir() ? path : info.path()));
 }
 
 bool Util::warnIfNotWritable(const QString &filePath, QWidget *parent, const QString &caption)
@@ -465,10 +467,18 @@ bool Util::hasDriveLetter(const QString &path)
     return driveSeparators == ":/" || driveSeparators == ":\\";
 }
 
+QColorDialog::ColorDialogOptions Util::getColorDialogOptions()
+{
+#if defined(Q_OS_UNIX) && !defined(Q_OS_MAC)
+    return QColorDialog::DontUseNativeDialog;
+#endif
+    return QColorDialog::ColorDialogOptions();
+}
+
 QFileDialog::Options Util::getFileDialogOptions()
 {
 #if defined(Q_OS_UNIX) && !defined(Q_OS_MAC)
-    if (qEnvironmentVariableIsSet("SNAP") || qEnvironmentVariableIsSet("GNOME_SHELL_SESSION_MODE")) {
+    if (qEnvironmentVariableIsSet("SNAP")) {
         return QFileDialog::DontUseNativeDialog;
     }
 #endif
@@ -990,3 +1000,263 @@ QString Util::getExecutable(QWidget *parent)
                                         nullptr,
                                         Util::getFileDialogOptions());
 }
+
+QPair<bool, bool> Util::dockerStatus(const QString &imageName)
+{
+    // Check if docker executable is available by running 'docker --version'.
+    QProcess proc;
+#if defined(Q_OS_UNIX) && !defined(Q_OS_MAC)
+    auto env = QProcessEnvironment::systemEnvironment();
+    env.remove("LD_LIBRARY_PATH");
+    proc.setProcessEnvironment(env);
+#endif
+    proc.start(Settings.dockerPath(), {"--version"});
+    if (!proc.waitForStarted(1000)) {
+        return qMakePair(false, false);
+    }
+    // Keep the timeout short to avoid UI stall.
+    if (!proc.waitForFinished(2000)) {
+        proc.kill();
+        return qMakePair(false, false);
+    }
+    bool dockerOk = proc.exitStatus() == QProcess::NormalExit && proc.exitCode() == 0;
+    if (!dockerOk) {
+        return qMakePair(false, false);
+    }
+    if (imageName.isEmpty()) {
+        return qMakePair(true, false);
+    }
+
+    // Query local images for the given name (may include tag). We avoid pulling.
+    // Use 'docker image inspect <imageName>' which returns 0 if present.
+    QProcess procImage;
+#if defined(Q_OS_UNIX) && !defined(Q_OS_MAC)
+    env = QProcessEnvironment::systemEnvironment();
+    env.remove("LD_LIBRARY_PATH");
+    procImage.setProcessEnvironment(env);
+#endif
+    procImage.start(Settings.dockerPath(), {"image", "inspect", imageName});
+    if (!procImage.waitForStarted(1000)) {
+        return qMakePair(true, false);
+    }
+    if (!procImage.waitForFinished(5000)) { // allow a bit more time here
+        procImage.kill();
+        return qMakePair(true, false);
+    }
+    bool imageOk = procImage.exitStatus() == QProcess::NormalExit && procImage.exitCode() == 0;
+    return qMakePair(true, imageOk);
+}
+
+// Helper to extract digest from 'docker manifest inspect' output.
+static QString digestFromManifestInspect(const QByteArray &json)
+{
+    auto s = QString::fromUtf8(json);
+    auto idx = s.indexOf("sha256:");
+    if (idx >= 0 && idx + 71 <= s.size()) {
+        return s.mid(idx, 71);
+    }
+    return QString();
+}
+
+static QSet<QString> dockerCurrentState;
+
+bool Util::isDockerImageCurrent(const QString &imageRef)
+{
+    if (imageRef.isEmpty()) {
+        return false;
+    }
+
+    // TODO: This comparison is not working outside of the machine on which I built the image.
+    // In the meantime, use check once per session per image ref.
+    if (dockerCurrentState.contains(imageRef))
+        return true;
+    dockerCurrentState << imageRef;
+    return false;
+
+    // Inspect (local/remote combined behavior) - this is a simplistic approach.
+    QProcess localProc;
+#if defined(Q_OS_UNIX) && !defined(Q_OS_MAC)
+    auto env = QProcessEnvironment::systemEnvironment();
+    env.remove("LD_LIBRARY_PATH");
+    localProc.setProcessEnvironment(env);
+#endif
+    localProc.start(Settings.dockerPath(), {"image", "inspect", imageRef});
+    if (!localProc.waitForStarted(1000) || !localProc.waitForFinished(4000)) {
+        if (localProc.state() != QProcess::NotRunning)
+            localProc.kill();
+    }
+    QString localDigest;
+    if (localProc.exitStatus() == QProcess::NormalExit && localProc.exitCode() == 0) {
+        localDigest = digestFromManifestInspect(localProc.readAllStandardOutput());
+    }
+
+    // Run again expecting remote freshness (will hit registry) without pulling.
+    QProcess remoteProc;
+#if defined(Q_OS_UNIX) && !defined(Q_OS_MAC)
+    env = QProcessEnvironment::systemEnvironment();
+    env.remove("LD_LIBRARY_PATH");
+    remoteProc.setProcessEnvironment(env);
+#endif
+    remoteProc.start(Settings.dockerPath(), {"manifest", "inspect", imageRef});
+    if (!remoteProc.waitForStarted(1000) || !remoteProc.waitForFinished(15000)) {
+        if (remoteProc.state() != QProcess::NotRunning)
+            remoteProc.kill();
+        return false;
+    }
+    if (remoteProc.exitStatus() != QProcess::NormalExit || remoteProc.exitCode() != 0) {
+        return false;
+    }
+    auto remoteDigest = digestFromManifestInspect(remoteProc.readAllStandardOutput());
+    return !remoteDigest.isEmpty() && !localDigest.isEmpty() && localDigest == remoteDigest;
+}
+
+void Util::isDockerImageCurrentAsync(const QString &imageRef,
+                                     QObject *receiver,
+                                     std::function<void(bool)> callback)
+{
+    if (!callback) {
+        return; // nothing to do
+    }
+    if (imageRef.isEmpty()) {
+        callback(false);
+        return;
+    }
+
+    // TODO: This comparison is not working outside of the machine on which I built the image.
+    // In the meantime, use check once per session per image ref.
+    if (dockerCurrentState.contains(imageRef)) {
+        callback(true);
+        return;
+    }
+    dockerCurrentState << imageRef;
+    callback(false);
+    return;
+
+    auto emitResult = [callback](bool result) {
+        QMetaObject::invokeMethod(
+            qApp, [callback, result]() { callback(result); }, Qt::QueuedConnection);
+    };
+
+    // Start with local inspect.
+    auto *localProc = new QProcess(receiver);
+
+#if defined(Q_OS_UNIX) && !defined(Q_OS_MAC)
+    auto env = QProcessEnvironment::systemEnvironment();
+    env.remove("LD_LIBRARY_PATH");
+    localProc->setProcessEnvironment(env);
+#endif
+
+    QObject::connect(localProc,
+                     &QProcess::errorOccurred,
+                     localProc,
+                     [localProc, emitResult](QProcess::ProcessError) {
+                         localProc->deleteLater();
+                         emitResult(false);
+                     });
+    QObject::connect(
+        localProc,
+        QOverload<int, QProcess::ExitStatus>::of(&QProcess::finished),
+        localProc,
+        [imageRef, receiver, emitResult, localProc](int, QProcess::ExitStatus) {
+            QString localDigest;
+            if (localProc->exitStatus() == QProcess::NormalExit && localProc->exitCode() == 0) {
+                localDigest = digestFromManifestInspect(localProc->readAllStandardOutput());
+            }
+            localProc->deleteLater();
+            // Remote manifest inspect regardless; if docker missing it will fail.
+            auto *remoteProc = new QProcess(receiver);
+
+#if defined(Q_OS_UNIX) && !defined(Q_OS_MAC)
+            auto env = QProcessEnvironment::systemEnvironment();
+            env.remove("LD_LIBRARY_PATH");
+            remoteProc->setProcessEnvironment(env);
+#endif
+
+            QObject::connect(remoteProc,
+                             &QProcess::errorOccurred,
+                             remoteProc,
+                             [remoteProc, emitResult](QProcess::ProcessError) {
+                                 remoteProc->deleteLater();
+                                 emitResult(false);
+                             });
+            QObject::connect(remoteProc,
+                             QOverload<int, QProcess::ExitStatus>::of(&QProcess::finished),
+                             remoteProc,
+                             [emitResult, remoteProc, localDigest](int, QProcess::ExitStatus) {
+                                 QString remoteDigest;
+                                 if (remoteProc->exitStatus() == QProcess::NormalExit
+                                     && remoteProc->exitCode() == 0) {
+                                     remoteDigest = digestFromManifestInspect(
+                                         remoteProc->readAllStandardOutput());
+                                 }
+                                 remoteProc->deleteLater();
+                                 bool current = !remoteDigest.isEmpty() && !localDigest.isEmpty()
+                                                && localDigest == remoteDigest;
+                                 emitResult(current);
+                             });
+            LOG_DEBUG() << "docker manifest inspect" << imageRef;
+            remoteProc->start(Settings.dockerPath(), {"manifest", "inspect", imageRef});
+        });
+    LOG_DEBUG() << "docker image inspect" << imageRef;
+    localProc->start(Settings.dockerPath(), {"image", "inspect", imageRef});
+}
+
+bool Util::isChromiumAvailable()
+{
+    // Check if Chromium executable file exists and is executable
+    QFileInfo fileInfo(Settings.chromiumPath());
+    return fileInfo.exists() && fileInfo.isExecutable();
+}
+
+bool Util::startDetached(const QString &program, const QStringList &arguments)
+{
+    QProcess process;
+
+#if defined(Q_OS_UNIX) && !defined(Q_OS_MAC)
+    // Remove parts of environment variables that our launch script has set
+    auto env = QProcessEnvironment::systemEnvironment();
+    // Get the parent of bin/shotcut
+    QString appDir = QFileInfo(QCoreApplication::applicationDirPath()).dir().absolutePath();
+
+    auto filterEnvVar = [&env, &appDir](const QString &varName) {
+        QString value = env.value(varName);
+        if (!value.isEmpty()) {
+            QStringList paths = value.split(':');
+            QStringList filtered;
+            for (QString &path : paths) {
+                if (!path.contains(appDir)) {
+                    filtered << path;
+                } else {
+                    LOG_DEBUG() << "removing" << path << "from env var" << varName;
+                }
+            }
+            env.insert(varName, filtered.join(':'));
+        }
+    };
+
+    filterEnvVar("FREI0R_PATH");
+    filterEnvVar("LADSPA_PATH");
+    filterEnvVar("LD_LIBRARY_PATH");
+    filterEnvVar("MANPATH");
+    filterEnvVar("PKG_CONFIG_PATH");
+    filterEnvVar("PYTHONHOME");
+
+    // These are relative paths and not cleanable with filterEnvVar()
+    env.remove("QML2_IMPORT_PATH");
+    env.remove("QT_PLUGIN_PATH");
+
+    process.setProcessEnvironment(env);
+#endif
+
+    return process.startDetached(program, arguments);
+}
+
+bool Util::openUrl(const QUrl &url)
+{
+    auto success = QDesktopServices::openUrl(url);
+#if defined(Q_OS_UNIX) && !defined(Q_OS_MAC)
+    if (!success)
+        success = startDetached("xdg-open", {url.toString()});
+#endif
+    return success;
+}
