@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012-2025 Meltytech, LLC
+ * Copyright (c) 2012-2026 Meltytech, LLC
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -50,6 +50,9 @@ ImageProducerWidget::ImageProducerWidget(QWidget *parent)
     , m_defaultDuration(-1)
 {
     ui->setupUi(this);
+#ifndef EXTERNAL_LAUNCHERS
+    delete ui->openWithButton;
+#endif
     Util::setColorsToHighlight(ui->filenameLabel, QPalette::Base);
 }
 
@@ -512,7 +515,7 @@ void ImageProducerWidget::on_openWithButton_clicked()
 #else
         const auto scheme = QLatin1String("file://");
 #endif
-        if (QDesktopServices::openUrl({scheme + filePath, QUrl::TolerantMode})) {
+        if (Util::openUrl({scheme + filePath, QUrl::TolerantMode})) {
             m_watcher.reset(new QFileSystemWatcher({filePath}));
             connect(m_watcher.get(),
                     &QFileSystemWatcher::fileChanged,
@@ -524,10 +527,10 @@ void ImageProducerWidget::on_openWithButton_clicked()
     menu.addSeparator();
     // custom options
     auto programs = Settings.filesOpenOther(kImageMediaType);
-    for (const auto &program : programs) {
+    for (auto &program : programs) {
         auto action = menu.addAction(QFileInfo(program).baseName(), this, [=]() {
             LOG_DEBUG() << program << filePath;
-            if (QProcess::startDetached(program, {QDir::toNativeSeparators(filePath)})) {
+            if (Util::startDetached(program, {QDir::toNativeSeparators(filePath)})) {
                 m_watcher.reset(new QFileSystemWatcher({filePath}));
                 connect(m_watcher.get(),
                         &QFileSystemWatcher::fileChanged,
@@ -561,7 +564,7 @@ void ImageProducerWidget::onOpenOtherAdd()
     const auto program = Util::getExecutable(&MAIN);
     if (!program.isEmpty()) {
         LOG_DEBUG() << program << filePath;
-        if (QProcess::startDetached(program, {QDir::toNativeSeparators(filePath)})) {
+        if (Util::startDetached(program, {QDir::toNativeSeparators(filePath)})) {
             Settings.setFilesOpenOther(kImageMediaType, program);
             m_watcher.reset(new QFileSystemWatcher({filePath}));
             connect(m_watcher.get(),
