@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2018-2024 Meltytech, LLC
+ * Copyright (c) 2018-2025 Meltytech, LLC
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -215,6 +215,14 @@ void NewProjectFolder::on_startButton_clicked()
         return;
     }
 
+    if (projectName.contains('?')) {
+        QMessageBox::warning(this,
+                             ui->newProjectLabel->text(),
+                             tr("The project name cannot include '?'."));
+        ui->startButton->setDisabled(true);
+        return;
+    }
+
     if (projectName.endsWith(".mlt"))
         projectName = projectName.mid(0, projectName.length() - 4);
     else
